@@ -12,12 +12,27 @@ from ._settings_store import Connector, settings_dir
 
 
 def get_connectore_file_url():
-    if "LAMIN_DEV" in os.environ:
-        if os.environ["LAMIN_DEV"] == "true":
+    if "LAMIN_ENV" in os.environ:
+        if os.environ["LAMIN_ENV"] == "dev":
             return "https://lamin-site-assets.s3.amazonaws.com/connector_dev.env"
+        elif os.environ["LAMIN_ENV"] == "test":
+            return "https://lamin-site-assets.s3.amazonaws.com/connector_test.env"
+        elif os.environ["LAMIN_ENV"] == "staging":
+            return "https://lamin-site-assets.s3.amazonaws.com/connector_staging.env"
     return "https://lamin-site-assets.s3.amazonaws.com/connector.env"
 
 
+def get_lamin_site_base_url():
+    if "LAMIN_ENV" in os.environ:
+        if os.environ["LAMIN_ENV"] == "dev":
+            return "http://localhost:3000"
+        elif os.environ["LAMIN_ENV"] == "test":
+            return "https://test.lamin.ai"
+        elif os.environ["LAMIN_ENV"] == "staging":
+            return "https://staging.lamin.ai"
+    return "https://lamin.ai"
+
+
 def connect_hub():
     file_url = get_connectore_file_url()
     connector_file, _ = urlretrieve(file_url)
@@ -41,7 +56,9 @@ def sign_up_hub(email) -> str:
     hub = connect_hub()
     password = id.secret()  # generate new password
     user = hub.auth.sign_up(
-        email=email, password=password, redirect_to="https://lamin.ai/signup"
+        email=email,
+        password=password,
+        redirect_to=f"{get_lamin_site_base_url()}/signup",
     )
     # if user already exists a fake user object without identity is returned
     if user.identities:
@@ -112,10 +129,12 @@ def push_instance_if_not_exists(storage):
         data = hub.table("storage").insert(storage_fields).execute().data
         assert len(data) == 1
 
-    # Warning: instance name is not unique
-    # we have to find another to check if an instance exists
     response = (
-        hub.table("instance").select("*").eq("name", settings.instance.name).execute()
+        hub.table("instance")
+        .select("*")
+        .eq("name", settings.instance.name)
+        .eq("owner_id", hub.auth.session().user.id.hex)
+        .execute()
     )
     if len(response.data) == 0:
         instance_fields = {
