@@ -1,3 +1,4 @@
+import os
 from dataclasses import dataclass
 from pathlib import Path
 from typing import Optional, Union
@@ -102,7 +103,7 @@ class Storage:
 class instance_description:
     storage_root = """Storage root. Either local dir, ``s3://bucket_name`` or ``gs://bucket_name``."""  # noqa
     storage_region = """Cloud storage region for s3 and Google Cloud."""
-    _dbconfig = """Either "sqlite" or "instance_name, postgres_url"."""
+    _dbconfig = """Either "sqlite" or postgres connection string."""
     name = """Instance name."""
     schema_modules = """Comma-separated string of schema modules. None if not set."""
 
@@ -120,9 +121,10 @@ class InstanceSettings:
     storage_region: Optional[str] = None
     """Cloud storage region for s3 and Google Cloud."""
     _dbconfig: str = "sqlite"
-    """Either "sqlite" or "instance_name, postgres_url"."""
+    """Either "sqlite" or postgres connection string."""
     schema_modules: Optional[str] = None  # type: ignore
     """Comma-separated string of schema modules. None if not set."""
+    _session: Optional[sqm.Session] = None
 
     @property
     def cloud_storage(self) -> bool:
@@ -186,6 +188,18 @@ class InstanceSettings:
         """Database engine."""
         return sqm.create_engine(self.db, future=future)
 
+    def session(self) -> sqm.Session:
+        """Database session."""
+        if "LAMIN_SKIP_MIGRATION" not in os.environ:
+            if self._session is None:
+                self._session = sqm.Session(self.db_engine(), expire_on_commit=False)
+            # should probably add a different check whether the session is still active
+            if not self._session.is_active:
+                self._session = sqm.Session(self.db_engine(), expire_on_commit=False)
+            return self._session
+        else:
+            return sqm.Session(self.db_engine(), expire_on_commit=False)
+
     @property
     def storage(self) -> Storage:
         """Low-level access to storage location."""
