@@ -36,6 +36,11 @@ def load_instance_settings(instance_settings_file: Path):
     return settings
 
 
+def load_instance_settings_from_store(settings_store: InstanceSettingsStore):
+    settings = setup_instance_from_store(settings_store)
+    return settings
+
+
 def load_or_create_user_settings():
     """Return current user settings."""
     if not current_user_settings_file.exists():
@@ -84,6 +89,7 @@ def setup_user_from_store(store: UserSettingsStore) -> UserSettings:
     settings = UserSettings()
     settings.email = store.email
     settings.password = store.password if store.password != "null" else None
+    settings.access_token = store.access_token
     settings.id = store.id if store.id != "null" else None
     settings.handle = store.handle if store.handle != "null" else None
     settings.name = store.name if store.name != "null" else None
